Name:           docbook-style-xsl
Version:        1.79.2
Release:        %mkrel 5
Group:          Publishing
Summary:        Norman Walsh's modular stylesheets for DocBook
License:        Copyright only
URL:            http://sourceforge.net/projects/docbook
Source0:        https://github.com/docbook/xslt10-stylesheets/releases/download/release%2F{%version}/docbook-xsl-nons-%{version}.tar.bz2
Source1:        https://github.com/docbook/xslt10-stylesheets/releases/download/release%2F{%version}/docbook-xsl-doc-%{version}.tar.bz2
Source2: %{name}.Makefile
#Avoid proportional-column-width for passivetex (bug #176766).
Patch1: docbook-xsl-pagesetup.patch
#Hard-code the margin-left work around to expect passivetex (bug #113456).
Patch2: docbook-xsl-marginleft.patch
#fix of #161619 - adjustColumnWidths now available
Patch3: docbook-xsl-newmethods.patch
#change a few non-constant expressions to constant - needed for passivetex(#366441)
Patch4: docbook-xsl-non-constant-expressions.patch
#added fixes for passivetex extension and list-item-body(#161371)
Patch5: docbook-xsl-list-item-body.patch
#workaround missing mandir section problem (#727251)
Patch6: docbook-xsl-mandir.patch
#Non-recursive string.subst that doesn't kill smb.conf.5 generation
Patch7: docbook-style-xsl-non-recursive-string-subst.patch
BuildArch:      noarch
Provides:	docbook-xsl = %{version}
Requires:	docbook-dtd-xml
Requires(post): libxml2-utils
Requires(postun): libxml2-utils
Requires(post): xml-common
Requires(postun): xml-common

%description
These XSL stylesheets allow to convert any DocBook document to another
printed (for example, RTF or PostScript) or online (for example, HTML) format.
They are highly customizable.

%package doc
Summary         : Documentation for DocBook stylesheets
Group           : Documentation

%description doc
This package contains the documentation for these stylesheets:
structure, customization, etc.

%prep
%setup -c -T -n docbook-xsl-%{version}
tar jxf %{SOURCE0}
mv docbook-xsl-nons-%{version}/* .
pushd ..
tar jxf %{SOURCE1}
popd

%patch1 -p1 -b .pagesetup
%patch2 -p1 -b .marginleft
%patch3 -p1 -b .newmethods
%patch4 -p1 -b .nonconstant
%patch5 -p1 -b .listitembody
%patch6 -p1 -b .mandir
%patch7 -p2 -b .non-recursive-subst

cp -p %{SOURCE2} Makefile

# fix of non UTF-8 files rpmlint warnings
for fhtml in $(find ./doc -name '*.html' -type f)
do
    iconv -f ISO-8859-1 -t UTF-8 "$fhtml" -o "$fhtml".tmp
    mv -f "$fhtml".tmp "$fhtml"
    sed -i 's/charset=ISO-8859-1/charset=UTF-8/' "$fhtml"
done

for f in $(find -name "*'*"); 
do
    mv -v "$f" $(echo "$f" | tr -d "'")
done

%build

%install
make install \
    BINDIR=%{buildroot}{_bindir} \
    DESTDIR=%{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}
cp -a VERSION.xsl \
    %{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}/VERSION.xsl
ln -sf xsl-stylesheets-%{version} \
    %{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets

rm -rf %{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets/extensions

%post
CATALOG=%{_sysconfdir}/xml/catalog
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
    "http://cdn.docbook.org/release/xsl-nons/%{version}" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
    "http://cdn.docbook.org/release/xsl-nons/%{version}" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
    "http://cdn.docbook.org/release/xsl-nons/current/" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
    "http://cdn.docbook.org/release/xsl-nons/current/" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
#keep the old one sourceforge URIs at least temporarily
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
    "http://docbook.sourceforge.net/release/xsl/current" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
    "http://docbook.sourceforge.net/release/xsl/current" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG

%postun
# do not remove on upgrade
if [ "$1" = 0 ]; then
    CATALOG=%{_sysconfdir}/xml/catalog
    %{_bindir}/xmlcatalog --noout --del \
        "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
fi

%files
%doc BUGS TODO README VERSION NEWS* COPYING INSTALL
%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}
%{_datadir}/sgml/docbook/xsl-stylesheets

%files doc
%doc doc docsrc


%changelog
* Mon Feb 24 2020 daviddavid <daviddavid> 1.79.2-5.mga8
+ Revision: 1549976
- don't ship the extensions as of it contains java source code, binary
  jars that are not compiled from source
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 1.79.2-4.mga7
+ Revision: 1278037
- Mageia 7 Mass Rebuild

* Sun May 06 2018 wally <wally> 1.79.2-3.mga7
+ Revision: 1226854
- require xml-common for post and postun
- fix libxml2-utils require

* Tue Jan 02 2018 wally <wally> 1.79.2-2.mga7
+ Revision: 1189762
- add patch from Debian (via Fedora) to modify string.subst to use the EXSLT 'replace' function when it is available

* Thu Sep 07 2017 guillomovitch <guillomovitch> 1.79.2-1.mga7
+ Revision: 1151811
- new version 1.79.2
- sync with fedora package

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.79.1-1.mga6
+ Revision: 918720
- 1.79.1

* Wed Oct 15 2014 umeabot <umeabot> 1.78.1-4.mga5
+ Revision: 745520
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.78.1-3.mga5
+ Revision: 678788
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.78.1-2.mga4
+ Revision: 523730
- Mageia 4 Mass Rebuild

* Fri May 24 2013 shlomif <shlomif> 1.78.1-1.mga4
+ Revision: 426505
- Get rid of tabs and trailing whitespace
- New version 1.78.1

* Fri Jan 11 2013 umeabot <umeabot> 1.78.0-2.mga3
+ Revision: 349047
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 24 2012 luigiwalser <luigiwalser> 1.78.0-1.mga3
+ Revision: 334765
- 1.78.0

* Sun Oct 14 2012 ennael <ennael> 1.77.1-3.mga3
+ Revision: 305358
- Documentation group

* Sun Aug 19 2012 pterjan <pterjan> 1.77.1-2.mga3
+ Revision: 282429
- Ship VERSION.xsl, it is included by other files

* Sun Aug 19 2012 luigiwalser <luigiwalser> 1.77.1-1.mga3
+ Revision: 282384
- 1.77.1

* Sun May 15 2011 pterjan <pterjan> 1.76.1-2.mga1
+ Revision: 98975
- Rebuild for fixed find-requires

* Mon Apr 18 2011 ahmad <ahmad> 1.76.1-1.mga1
+ Revision: 87544
- update to 1.76.1
- fix License (Fedora)

* Sun Jan 09 2011 blino <blino> 1.75.2-5.mga1
+ Revision: 1550
- remove old file migration and version check
- imported package docbook-style-xsl


* Mon Nov 15 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 1.75.2-4mdv2011.0
+ Revision: 597783
- package xhtml-1_1 too

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 1.75.2-3mdv2010.1
+ Revision: 520693
- rebuilt for 2010.1

* Tue Oct 06 2009 Thierry Vignaud <tv@mandriva.org> 1.75.2-2mdv2010.0
+ Revision: 454763
- do not package huge release notes

* Thu Jul 23 2009 Frederik Himpe <fhimpe@mandriva.org> 1.75.2-1mdv2010.0
+ Revision: 398996
- update to new version 1.75.2

* Sun May 31 2009 Frederik Himpe <fhimpe@mandriva.org> 1.75.1-1mdv2010.0
+ Revision: 381608
- Add %%mkrel and clean up SPEC file a bit
- update to new version 1.75.1

* Wed Mar 18 2009 Funda Wang <fwang@mandriva.org> 1.74.3-1mdv2009.1
+ Revision: 357093
- New version 1.74.3

* Thu Jan 08 2009 Emmanuel Andry <eandry@mandriva.org> 1.74.0-1mdv2009.1
+ Revision: 327251
- New version 1.74.0

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 1.73.2-4mdv2009.0
+ Revision: 220678
- rebuild

* Sat Jan 12 2008 Thierry Vignaud <tv@mandriva.org> 1.73.2-3mdv2008.1
+ Revision: 149206
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Thu Sep 06 2007 Camille Bégnis <camille@mandriva.com> 1.73.2-2mdv2008.0
+ Revision: 80885
- remove manpage patch not needed since 1.73.1

* Fri Aug 31 2007 Funda Wang <fwang@mandriva.org> 1.73.2-1mdv2008.0
+ Revision: 76391
- New version 1.73.2

* Thu Aug 16 2007 Thierry Vignaud <tv@mandriva.org> 1.73.0-3mdv2008.0
+ Revision: 64209
- rebuild

* Fri Jul 27 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 1.73.0-2mdv2008.0
+ Revision: 56415
- Added patch manpages_charmap from
  https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=249294
  Fixes a problem I saw while building git with latest
  docbook-style-xsl.

* Mon Jul 23 2007 Funda Wang <fwang@mandriva.org> 1.73.0-1mdv2008.0
+ Revision: 54721
- New version


* Wed Jan 24 2007 Camille Bégnis <camille@mandriva.com> 1.72.0-1mdv2007.0
+ Revision: 112758
- Import docbook-style-xsl

* Wed Jan 24 2007 Camille Begnis <camille@mandriva.com> 1.72.0-1mdv2007.1
- 1.72.0
- docsrc is back

* Thu Oct 05 2006 Camille Begnis <camille@mandriva.com> 1.71.0-1mdv2007.0
- New version 1.71.0

* Tue May 30 2006 Camille Begnis <camille@mandriva.com> 1.70.1-1mdv2007.0
- 1.70.1

* Wed Aug 17 2005 Camille Begnis <camille@mandriva.com> 1.69.1-1mdk
- 1.69.1
- replaces prereq with Requires(pre)

* Tue Jul 19 2005 Camille Begnis <camille@mandrakesoft.com> 1.69.0-1mdk
- 1.69.0
- doc is now in a separate archive

* Thu Feb 24 2005 Camille Begnis <camille@mandrakesoft.com> 1.68.1-1mdk
- 1.68.1

* Thu Feb 24 2005 Camille Bégnis <camille@mandrakesoft.com> 1.67.2-3mdk
- Rebuild

* Mon Feb 07 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 1.67.2-2mdk 
- Fix catalog registration on upgrade/uninstall

* Thu Dec 02 2004 Camille Begnis <camille@mandrakesoft.com> 1.67.2-1mdk
- 1.67.2
- remove unneeded libxml2-utils prereq...

* Tue Nov 23 2004 Camille Begnis <camille@mandrakesoft.com> 1.67.0-2mdk
- fix license to please rpmlint
- added libxml2-utils prereq for xmlcatalog [Bug 12470]

* Fri Nov 19 2004 Camille Begnis <camille@mandrakesoft.com> 1.67.0-1mdk
- 1.67.0
- adjust installation accordingly

* Tue Sep 14 2004 <camille@mandrakesoft.com> 1.66.0-1mdk
- New release 1.66.0

* Wed Apr 28 2004 <camille@mandrakesoft.com> 1.65.1-1mdk
- New release 1.65.1

